//
//  Created by baidu.
//  Copyright © 2018年 baidu. All rights reserved.
//
#include "InterstitialAdScene.h"
#include "VideoAdScene.h"
#include "GameSceneUtils.h"
#include "DAPInterstitialAd.h"

USING_NS_CC;
using namespace dap::audience_network;
 
void adDidLoad() {
    setStatus<InterstitialAdScene>("ad did load", InterstitialAdSceneTag);
}

void adDidShow() {
    setStatus<InterstitialAdScene>("ad did show", InterstitialAdSceneTag);
}

void adDidClick() {
    setStatus<InterstitialAdScene>("ad did click", InterstitialAdSceneTag);
}

void adDidClose() {
    setStatus<InterstitialAdScene>("ad did close", InterstitialAdSceneTag);
}

void adDidFailWithError(int error) {
    setStatus<InterstitialAdScene>("ad load error", InterstitialAdSceneTag);
}

Scene* interstitialAdScene = NULL;

Scene* InterstitialAdScene::Scene()
{
    if (interstitialAdScene) {
        return interstitialAdScene;
    }
    
    auto scene = Scene::create();
    
    auto layer = InterstitialAdScene::create();
    
    scene->addChild(layer, 0, InterstitialAdSceneTag);
    
    interstitialAdScene = scene;
    
    return scene;
}

bool InterstitialAdScene::init()
{
    if ( !Layer::init() )
    {
        return false;
    }
    
    auto visibleSize = Director::getInstance()->getVisibleSize();
    Vec2 origin = Director::getInstance()->getVisibleOrigin();
    
    MenuItemImage *loadButtonItem = MenuItemImage::create(
                                                      "button_background.png",
                                                      "button_background.png",
                                                      CC_CALLBACK_1(InterstitialAdScene::menuLoadAdCallback, this));
    
    loadButtonItem->setPosition(Vec2(origin.x + visibleSize.width/2 ,
                                 origin.y + visibleSize.height * 0.8));
    
    Label *loadMenulabel = Label::createWithTTF("Load", "fonts/Marker Felt.ttf", 8);
    
    loadMenulabel->setPosition(Vec2(loadButtonItem->getContentSize().width/2, loadButtonItem->getContentSize().height/2));
    
    loadButtonItem->addChild(loadMenulabel, 1);
    
    Menu *loadMenu = Menu::create(loadButtonItem, NULL);
    loadMenu->setPosition(Vec2::ZERO);
    this->addChild(loadMenu, 1);
    
    MenuItemImage *fillButtonItem = MenuItemImage::create(
                                                          "button_background.png",
                                                          "button_background.png",
                                                          CC_CALLBACK_1(InterstitialAdScene::menuFillAdCallback, this));
    
    fillButtonItem->setPosition(Vec2(origin.x + visibleSize.width/2 ,
                                     origin.y + visibleSize.height * 0.7));
    
    Label *fillMenulabel = Label::createWithTTF("Fill", "fonts/Marker Felt.ttf", 8);
    
    fillMenulabel->setPosition(Vec2(fillButtonItem->getContentSize().width/2, fillButtonItem->getContentSize().height/2));
    
    fillButtonItem->addChild(fillMenulabel, 1);
    
    Menu *fillMenu = Menu::create(fillButtonItem, NULL);
    fillMenu->setPosition(Vec2::ZERO);
    this->addChild(fillMenu, 1);
    
    MenuItemImage *showButtonItem = MenuItemImage::create(
                                                      "button_background.png",
                                                      "button_background.png",
                                                      CC_CALLBACK_1(InterstitialAdScene::menuShowAdCallback, this));
    
    showButtonItem->setPosition(Vec2(origin.x + visibleSize.width/2 ,
                                 origin.y + visibleSize.height * 0.6));
    
    Label *showMenulabel = Label::createWithTTF("Show", "fonts/Marker Felt.ttf", 8);
    
    showMenulabel->setPosition(Vec2(showButtonItem->getContentSize().width/2, showButtonItem->getContentSize().height/2));
    
    showButtonItem->addChild(showMenulabel, 1);
    
    Menu *showMenu = Menu::create(showButtonItem, NULL);
    showMenu->setPosition(Vec2::ZERO);
    this->addChild(showMenu, 1);
    
    MenuItemImage *sceneButtonItem = MenuItemImage::create(
                                                          "button_background.png",
                                                          "button_background.png",
                                                          CC_CALLBACK_1(InterstitialAdScene::nextScene, this));
    
    sceneButtonItem->setPosition(Vec2(origin.x + visibleSize.width/2 ,
                                     origin.y + visibleSize.height * 0.5));
    
    Label *sceneMenulabel = Label::createWithTTF("Next Scene", "fonts/Marker Felt.ttf", 8);
    
    sceneMenulabel->setPosition(Vec2(sceneButtonItem->getContentSize().width/2, sceneButtonItem->getContentSize().height/2));
    
    sceneButtonItem->addChild(sceneMenulabel, 1);
    
    Menu *sceneMenu = Menu::create(sceneButtonItem, NULL);
    sceneMenu->setPosition(Vec2::ZERO);
    this->addChild(sceneMenu, 1);

    
    auto label = Label::createWithTTF("Interstitial", "fonts/Marker Felt.ttf", 24);

    label->setPosition(Vec2(origin.x + visibleSize.width/2,
                            origin.y + visibleSize.height - label->getContentSize().height));

    this->addChild(label, 1);
    
    if (this->dapinterstitialAd) {
        this->dapinterstitialAd.reset();
    }
    
    this->dapinterstitialAd = std::make_shared<DAPInterstitialAd>(130745, INTERSTITIAL_TYPE::NOMAL);

    return true;
}

void InterstitialAdScene::menuLoadAdCallback(Ref* pSender)
{
    this->dapinterstitialAd->onRecevie = adDidLoad;
    this->dapinterstitialAd->onPresent = adDidShow;
    this->dapinterstitialAd->onClick = adDidClick;
    this->dapinterstitialAd->onDismiss = adDidClose;
    this->dapinterstitialAd->onDAPAdError = adDidFailWithError;
    this->dapinterstitialAd->loadAd();
}

void InterstitialAdScene::menuFillAdCallback(Ref* pSender)
{
    this->dapinterstitialAd->fillAd();
}

void InterstitialAdScene::menuShowAdCallback(Ref* pSender)
{
    if (this->dapinterstitialAd) {
        this->dapinterstitialAd->showAd();
    }
}

void InterstitialAdScene::setStatus(std::string msg) {
    if (!this->adLabel) {
        auto visibleSize = Director::getInstance()->getVisibleSize();
        Vec2 origin = Director::getInstance()->getVisibleOrigin();
        auto label = Label::createWithTTF(msg, "fonts/Marker Felt.ttf", 8);
        
        label->setPosition(Vec2(origin.x + visibleSize.width/2,
                                origin.y + visibleSize.height * 0.1));
        
        this->addChild(label, 1);
        this->adLabel = label;
    } else {
        this->adLabel->setString(msg);
    }
}

void InterstitialAdScene::nextScene(Ref* pSender) {
    Director::getInstance()->pushScene(VideoAdScene::Scene());
}


