//
//  Created by baidu.
//  Copyright © 2018年 baidu. All rights reserved.
//
#include "VideoAdScene.h"
#include "NativeAdScene.h"
#include "DAPVideoAd.h"
#include "GameSceneUtils.h"

USING_NS_CC;
using namespace dap::audience_network;


void adStart() {
    setStatus<VideoAdScene>("ad start", VideoAdSceneTag);
}

void adPlayable() {
    setStatus<VideoAdScene>("ad playable", VideoAdSceneTag);
}

void adEnd(bool isSuccessfulView, bool isCallToActionClicked) {
    setStatus<VideoAdScene>("ad end", VideoAdSceneTag);
}

void adError(int errorCode) {
    setStatus<VideoAdScene>("ad error", VideoAdSceneTag);
}

Scene* videoAdScene = NULL;
Scene* VideoAdScene::Scene()
{
    if (videoAdScene) {
        return videoAdScene;
    }
    
    auto scene = Scene::create();
    
    auto layer = VideoAdScene::create();
    
    scene->addChild(layer, 0, VideoAdSceneTag);
    
    videoAdScene = scene;
    
    return scene;
}

bool VideoAdScene::init()
{
    if ( !Layer::init() )
    {
        return false;
    }
    
    auto visibleSize = Director::getInstance()->getVisibleSize();
    Vec2 origin = Director::getInstance()->getVisibleOrigin();
    
    MenuItemImage *loadButtonItem = MenuItemImage::create(
                                                      "button_background.png",
                                                      "button_background.png",
                                                      CC_CALLBACK_1(VideoAdScene::menuLoadAdCallback, this));
    
    loadButtonItem->setPosition(Vec2(origin.x + visibleSize.width/2 ,
                                 origin.y + visibleSize.height * 0.8));
    
    Label *loadMenulabel = Label::createWithTTF("Load", "fonts/Marker Felt.ttf", 8);
    
    loadMenulabel->setPosition(Vec2(loadButtonItem->getContentSize().width/2, loadButtonItem->getContentSize().height/2));
    
    loadButtonItem->addChild(loadMenulabel, 1);
    
    Menu *loadMenu = Menu::create(loadButtonItem, NULL);
    loadMenu->setPosition(Vec2::ZERO);
    this->addChild(loadMenu, 1);
    
    MenuItemImage *playableButtonItem = MenuItemImage::create(
                                                          "button_background.png",
                                                          "button_background.png",
                                                          CC_CALLBACK_1(VideoAdScene::menuPlayableAdCallback, this));
    
    playableButtonItem->setPosition(Vec2(origin.x + visibleSize.width/2 ,
                                     origin.y + visibleSize.height * 0.7));
    
    Label *playableMenulabel = Label::createWithTTF("Playable", "fonts/Marker Felt.ttf", 8);
    
    playableMenulabel->setPosition(Vec2(playableButtonItem->getContentSize().width/2, playableButtonItem->getContentSize().height/2));
    
    playableButtonItem->addChild(playableMenulabel, 1);
    
    Menu *playableMenu = Menu::create(playableButtonItem, NULL);
    playableMenu->setPosition(Vec2::ZERO);
    this->addChild(playableMenu, 1);
   
    
    
    
    MenuItemImage *showButtonItem = MenuItemImage::create(
                                                      "button_background.png",
                                                      "button_background.png",
                                                      CC_CALLBACK_1(VideoAdScene::menuShowAdCallback, this));
    
    showButtonItem->setPosition(Vec2(origin.x + visibleSize.width/2 ,
                                 origin.y + visibleSize.height * 0.6));
    
    Label *showMenulabel = Label::createWithTTF("Show", "fonts/Marker Felt.ttf", 8);
    
    showMenulabel->setPosition(Vec2(showButtonItem->getContentSize().width/2, showButtonItem->getContentSize().height/2));
    
    showButtonItem->addChild(showMenulabel, 1);
    
    Menu *showMenu = Menu::create(showButtonItem, NULL);
    showMenu->setPosition(Vec2::ZERO);
    this->addChild(showMenu, 1);

    MenuItemImage *sceneButtonItem = MenuItemImage::create(
                                                           "button_background.png",
                                                           "button_background.png",
                                                           CC_CALLBACK_1(VideoAdScene::nextScene, this));
    
    sceneButtonItem->setPosition(Vec2(origin.x + visibleSize.width/2 ,
                                      origin.y + visibleSize.height * 0.5));
    
    Label *sceneMenulabel = Label::createWithTTF("Next Scene", "fonts/Marker Felt.ttf", 8);
    
    sceneMenulabel->setPosition(Vec2(sceneButtonItem->getContentSize().width/2, sceneButtonItem->getContentSize().height/2));
    
    sceneButtonItem->addChild(sceneMenulabel, 1);
    
    Menu *sceneMenu = Menu::create(sceneButtonItem, NULL);
    sceneMenu->setPosition(Vec2::ZERO);
    this->addChild(sceneMenu, 1);
    
    auto label = Label::createWithTTF("Video", "fonts/Marker Felt.ttf", 24);

    label->setPosition(Vec2(origin.x + visibleSize.width/2,
                            origin.y + visibleSize.height - label->getContentSize().height));

    this->addChild(label, 1);
    
    if (this->videoAd) {
        this->videoAd.reset();
    }
    this->videoAd = std::make_shared<DAPVideoAd>(140365);
    
    return true;
}

void VideoAdScene::menuLoadAdCallback(Ref* pSender)
{
    this->videoAd->onStart = adStart;
    this->videoAd->onPlayable = adPlayable;
    this->videoAd->onEnd = adEnd;
    this->videoAd->onError = adError;
    this->videoAd->loadAd();
}


void VideoAdScene::menuPlayableAdCallback(Ref* pSender)
{
    if (this->videoAd->isAdPlayable()) {
        setStatus("True");
    } else {
        setStatus("false");
    }
}

void VideoAdScene::menuShowAdCallback(Ref* pSender)
{
    this->videoAd->playAd();
}

void VideoAdScene::setStatus(std::string msg) {
    if (!this->adLabel) {
        auto visibleSize = Director::getInstance()->getVisibleSize();
        Vec2 origin = Director::getInstance()->getVisibleOrigin();
        auto label = Label::createWithTTF(msg, "fonts/Marker Felt.ttf", 8);
        
        label->setPosition(Vec2(origin.x + visibleSize.width/2,
                                origin.y + visibleSize.height * 0.2));
        
        this->addChild(label, 1);
        this->adLabel = label;
    } else {
        this->adLabel->setString(msg);
    }
}

void VideoAdScene::nextScene(Ref* pSender) {
    Director::getInstance()->pushScene(NativeAdScene::Scene());
}


